@@ -92,14 +92,13 @@ class FollowLog:
                 yield from self.process(part.decode())
 
 
-class Render:
-    def __init__(self, scene: PurePosixPath, client):
-        self.scene = scene
-        self.client = client
+class Scene:
+    def __init__(self, scene: str):
+        self.path = PurePosixPath(scene)
 
     @property
     def task_id(self):
-        return self.scene.parent
+        return self.path.parent
 
     @property
     def workdir(self):
@@ -109,16 +108,22 @@ class Render:
 
     @property
     def filename(self):
-        return self.scene.name
+        return self.path.name
 
     @property
-    def local_scene(self):
+    def localfile(self):
         return self.workdir / 'scene' / self.filename
 
+
+class Render:
+    def __init__(self, scene: Scene, client: aws.S3):
+        self.scene = scene
+        self.client = client
+
     def run(self, extension='exr'):
-        self.client.download_file(self.scene, self.local_scene)
-        logger.info(f"Scene downloaded - {self.local_scene}")
-        if not self.local_scene.is_file():
+        self.client.download_file(self.scene.path, self.scene.localfile)
+        logger.info(f"Scene downloaded - {self.scene.localfile}")
+        if not self.scene.localfile.is_file():
             raise Exception("Local file does not exists")
 
         max_cmd = Path(os.environ['ADSK_3DSMAX_x64_2018']) / '3dsmaxcmd'
@@ -126,18 +131,18 @@ class Render:
             str(max_cmd),
             "-continueOnError",
             "-batchRender",
-            f'-outputName:{str(self.workdir / f"0.{extension}")}',
-            str(self.local_scene)],
+            f'-outputName:{str(self.scene.workdir / f"0.{extension}")}',
+            str(self.scene.localfile)],
             stderr=STDOUT,
             stdout=PIPE,
             bufsize=1,
         )
 
-        follow = FollowLog(self.workdir, extension)
+        follow = FollowLog(self.scene.workdir, extension)
         for file in follow.iterate_files(process.stdout):
             view = file.parent.name
             self.client.upload_file(
-                self.task_id / 'result' / view / file.name,
+                self.scene.task_id / 'result' / view / file.name,
                 file
             )
             logger.info(f"Artifact is uploaded - {file}")
@@ -147,42 +152,64 @@ class Render:
 
 def record_time(f):
     def format_date(value: datetime):
-        return value.strftime('%H:%M %d:%m:%Y')
+        return value.strftime('%H:%M:%S %d-%m-%Y')
 
     def wrapper(*args, **kwargs):
         begin = datetime.now()
-        logger.info(f"Started: {format_date(begin)}")
+        logger.info(f"Rendering is started!")
         try:
             return f(*args, **kwargs)
         finally:
             end = datetime.now()
-            logger.info(f"Finished: {format_date(end)}")
+            logger.info(f"Rendering is finished!")
             logger.info(f"Took: {str(end - begin).split('.')[0]}")
 
     return wrapper
 
 
-def _run(scene):
-    s3 = aws.S3(
-        os.environ['AWS_BUCKET'],
-        aws_access_key_id=os.environ['AWS_ACCESS_KEY_ID'],
-        aws_secret_access_key=os.environ['AWS_SECRET_ACCESS_KEY'],
-        endpoint_url=os.environ['AWS_ENDPOINT'],
-    )
-    render = Render(PurePosixPath(scene), client=s3)
-    # should be before run
-    configure_logger(render.workdir, level=logging.getLevelName(DEBUG))
-    rc = record_time(render.run)()
-    if rc > 0:
-        raise Exception(f"3dsmax returned non zero code {rc}")
+def collect_logs(scene: Scene, client: aws.S3):
+    logger.info("Collecting log files...")
+    for file in itertools.chain(
+            # additional logs could be appended here
+            glob.glob(str(Path(os.environ['LOG_DIR']) / '*.log')),
+            glob.glob(str(scene.workdir / '*.log')),
+    ):
+        logger.info(f"Found log {file}")
+        client.upload_file(
+            scene.task_id / 'logs' / os.path.basename(file),
+            file
+        )
 
 
-@celery.task(name="run")
-def run(scene):
+def run(scene_key):
     assert os.environ['ADSK_3DSMAX_x64_2018'], "ADSK_3DSMAX_x64_2018 must be defined"
     assert os.environ['AWS_ACCESS_KEY_ID'], "AWS_ACCESS_KEY_ID must be defined"
     assert os.environ['AWS_SECRET_ACCESS_KEY'], "AWS_SECRET_ACCESS_KEY must be defined"
     assert os.environ['AWS_ENDPOINT'], "AWS_ENDPOINT must be defined"
     assert os.environ['AWS_BUCKET'], "AWS_BUCKET must be defined"
     assert os.environ['LOG_DIR'], "LOG_DIR must be defined"
-    return _run(scene)
+    s3 = aws.S3(
+        os.environ['AWS_BUCKET'],
+        aws_access_key_id=os.environ['AWS_ACCESS_KEY_ID'],
+        aws_secret_access_key=os.environ['AWS_SECRET_ACCESS_KEY'],
+        endpoint_url=os.environ['AWS_ENDPOINT'],
+    )
+    scene = Scene(scene_key)
+    # configure current logger for the specific scene
+    configure_logger(scene.workdir, level=logging.getLevelName(DEBUG))
+
+    render = Render(scene, client=s3)
+    try:
+        rc = record_time(render.run)()
+        if rc > 0:
+            raise Exception(f"3dsmax returned non zero code {rc}")
+    except Exception as e:
+        logger.exception(e)
+        raise
+    finally:
+        collect_logs(scene, s3)
+
+
+@celery.task(name="run")
+def main(*args, **kwargs):
+    run(*args, **kwargs)
