@@ -42,8 +42,10 @@ def iterate_files():
 
 
 def check_files():
-    for file in iterate_files():
-        hex = sha256(file)
+    # for file in iterate_files():
+    #     hex = sha256(file)
+    pass
+
 
 
 def main(delay):
